# -*- coding: utf-8 -*-
################################################################################
#
# ROSA Crypto
#
# Copyright (c) 2016-2017, LLC "NTC IT ROSA"
# License: BSD
# Authors:
#     Michl Voznesensky <m.voznesensky@rosalinux.ru>
#
# This file is a part of ROSA Crypto
#
# All rights reserved.
#
#  Redistribution and use in source and binary forms, with or without
#  modification, are permitted provided that the following conditions are
#  met:
#
#  * Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#  * Redistributions in binary form must reproduce the above
#    copyright notice, this list of conditions and the following disclaimer
#    in the documentation and/or other materials provided with the
#    distribution.
#  * Neither the name of the LLC "NTC IT ROSA" nor the names of its
#    contributors may be used to endorse or promote products derived from
#    this software without specific prior written permission.
#
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
#  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
#  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
#  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
#  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
#  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
#  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
#  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
################################################################################

import re
import gettext
gettext.install('rosa-crypto-tool')

# Dictionary all available CryptoPro errors
errors = {"0x20000064": _("Little memory"),#Мало памяти
		  "0x20000065": _("Failed to open file"),#Не удалось открыть файл
		  "0x20000066": _("Operation cancelled by the user"),#Операция отменена пользователем
		  "0x20000067": _("Incorrect BASE64 conversion"),#Некорректное преобразование BASE64
		  "0x20000068": _("If you specify -help option, others should not be"),#Если указан параметр -help, то других быть не должно
		  "0x200000c8": _("Specify the extra file"),#Указан лишний файл
		  "0x200000c9": _("Set unknown key"),#Указан неизвестный ключ
		  "0x200000ca": _("Specified excess command"),#Указана лишняя команда
		  "0x200000cb": _("Key not specified"),#Для ключа не указан параметр
		  "0x200000cc": _("Not specified, the command"),#Не указана команда
		  "0x200000cd": _("Not specified required key"),#Не указан необходимый ключ
		  "0x200000ce": _("Invalid key"),#Указан неверный ключ
		  "0x200000cf": _("The key parameter -q must be a positive integer"),#Параметром ключа -q должно быть натуральное число
		  "0x200000d0": _("No input file specified"),#Не указан входной файл
		  "0x200000d1": _("Do not specify an output file"),#Не указан выходной файл
		  "0x200000d2": _("The command does not use a parameter with the name of the file"),#Команда не использует параметр с именем файла
		  "0x200000d3": _("Do not specify a message file"),#Не указан файл сообщения
		  "0x2000012c": _("Failed to open certificate store"),#Не удалось открыть хранилище сертификатов
		  "0x2000012d": _("Certificates not found"),#Сертификаты не найдены
		  "0x2000012e": _("Found more than one certificate (key -1)"),#Найдено более одного сертификата (ключ -1)
		  "0x2000012f": _("The team involves the use of only one certificate"),#Команда подразумевает использование только одного сертификата
		  "0x20000130": _("Wrong number"),#Неверно указан номер
		  "0x20000131": _("No certificates"),#Нет используемых сертификатов
		  "0x20000132": _("This certificate cannot be used for this operation"),#Данный сертификат не может применяться для этой операции
		  "0x20000133": _("The certificate chain is not validated. Either the certificate was revoked or expired."),#Цепочка сертификатов не проверена. Либо сертификат был отозван или срок действия истек
		  "0x20000134": _("Cryptographic service provider that supports the necessary algorithm was not found"),#Криптопровайдер, поддерживающий необходимый алгоритм не найден
		  "0x20000135": _("Failed password key container"),#Неудачный ввод пароля ключевого контейнера
		  "0x20000136": _("Communication error with the private key"),#Ошибка связи с закрытым ключом
		  "0x20000190": _("Not specified mask files"),#Не указана маска файлов
		  "0x20000191": _("Specify multiple file masks"),#Указаны несколько масок файлов
		  "0x20000192": _("Files not found"),#Файлы не найдены
		  "0x20000193": _("Using the wrong mask"),#Задана неверная маска
		  "0x20000194": _("Wrong hash"),#Неверный хеш
		  "0x200001f4": _("Key -start is specified and the output file no"),#Ключ -start указан, а выходной файл нет
		  "0x200001f5": _("The contents of the file is not signed message"),#Содержимое файла - не подписанное сообщение
		  "0x200001f6": _("Unknown signature algorithm"),#Неизвестный алгоритм подписи
		  "0x200001f7": _("The certificate of the signatory was not found"),#Сертификат автора подписи не найден
		  "0x200001f8": _("Signature not found"),#Подпись не найдена
		  "0x200001f9": _("Signature is not correct"),#Подпись не верна
		  "0x20000200": _("The time stamp is not correct"),#Штамп времени не верен
		  "0x20000258": _("The contents of the file is not an encrypted message"),#Содержимое файла - не зашифрованное сообщение
		  "0x20000259": _("Unknown encryption algorithm"),#Неизвестный алгоритм шифрования
		  "0x2000025a": _("Not found the certificate with the corresponding private key"),#Не найден сертификат с соответствующим секретным ключом
		  "0x200002bc": _("Failed to initialize cOM"),#Не удалось инициализировать cOM
		  "0x200002bd": _("Containers not found"),#Контейнеры не найдены
		  "0x200002be": _("Failed to get a response from the server"),#Не удалось получить ответ от сервера
		  "0x200002bf": _("Certificate not found in server response"),#Сертификат не найден в ответе сервера
		  "0x200002c0": _("The file does not contain the request ID"),#Файл не содержит идентификатор запроса
		  "0x200002c1": _("Incorrect address CC"),#Некорректный адрес ЦС
		  "0x200002c2": _("Received invalid cookie"),#Получен неверный cookie
		  "0x20000320": _("The serial number contains invalid number of characters"),#Серийный номер содержит недопустимое количество символов
		  "0x20000321": _("Invalid product code"),#Неверный код продукта
		  "0x20000322": _("Unable to verify serial number"),#Не удалось проверить серийный номер
		  "0x20000323": _("Unable to save serial number"),#Не удалось сохранить серийный номер
		  "0x20000324": _("Failed to load serial number"),#Не удалось загрузить серийный номер
		  "0x20000325": _("License expired"),#Лицензия просрочена
		  "0x80091004": _("This file is not encrypted")
		  }

def searchError(output_mess):
	""" Find error code and return it and it message errors if have """
	
	# ?: - don't capture fragment into group
	error_code = re.search(r'(?:ErrorCode: |ReturnCode: )(\w+)', output_mess).group(1)
	return (error_code, errors.get(error_code))

if __name__ == '__main__':
	
	print("You run the part program rosa crypto tool, please launch the main file")
	
